from typing import TypeVar

#This Types are used for typing hints

_Root = TypeVar("_Root")